==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/ReportTemplateAreaSqlFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link ReportTemplateAreaSql}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class ReportTemplateAreaSqlFieldAttributes extends AbstractBeanAttributesDefinition{

    /** id (Database column: ID - ID column) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDescription("ID column")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("REPORT_TEMPLATE_AREA_SQL")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** name (Database column: NAME - The sql business name) */
    static public AttributeDefinition name =
        new AttributeDefinition("name")
                .setDescription("The sql business name")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("REPORT_TEMPLATE_AREA_SQL")
                .setDatabaseId("NAME")
                .setMandatory(true)
                .setMaxSize(100)
                .setType(String.class);

    /** reportTemplateArea (Database column: REPORT_AREA_ID - the report area ID) */
    static public AttributeDefinition reportTemplateArea =
        new AttributeDefinition("reportTemplateArea")
                .setDescription("the report area ID")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("REPORT_TEMPLATE_AREA_SQL")
                .setDatabaseId("REPORT_AREA_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplateArea.class)
                .setLovDataClassKey("id")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplateArea.class);

    /** sql (Database column: SQL - the SQL query) */
    static public AttributeDefinition sql =
        new AttributeDefinition("sql")
                .setDescription("the SQL query")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("REPORT_TEMPLATE_AREA_SQL")
                .setDatabaseId("SQL")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** sqlDataSource (Database column: SQL_DATA_SOURCE_ID - the data source ID) */
    static public AttributeDefinition sqlDataSource =
        new AttributeDefinition("sqlDataSource")
                .setDescription("the data source ID")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("REPORT_TEMPLATE_AREA_SQL")
                .setDatabaseId("SQL_DATA_SOURCE_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.SqlDataSource.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.SqlDataSource.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(id.getName(),id);
        map.put(name.getName(),name);
        map.put(reportTemplateArea.getName(),reportTemplateArea);
        map.put(sql.getName(),sql);
        map.put(sqlDataSource.getName(),sqlDataSource);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/ReportTemplateAreaSqlFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link ReportTemplateAreaSql}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class ReportTemplateAreaSqlFieldAttributes extends AbstractBeanAttributesDefinition{

    /** id (Database column: ID - ID column) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDescription("ID column")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("REPORT_TEMPLATE_AREA_SQL")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(10)
                .setType(Long.class);

    /** name (Database column: NAME - The sql business name) */
    static public AttributeDefinition name =
        new AttributeDefinition("name")
                .setDescription("The sql business name")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("REPORT_TEMPLATE_AREA_SQL")
                .setDatabaseId("NAME")
                .setMandatory(true)
                .setMaxSize(100)
                .setType(String.class);

    /** reportTemplateArea (Database column: REPORT_AREA_ID - the report area ID) */
    static public AttributeDefinition reportTemplateArea =
        new AttributeDefinition("reportTemplateArea")
                .setDescription("the report area ID")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("REPORT_TEMPLATE_AREA_SQL")
                .setDatabaseId("REPORT_AREA_ID")
                .setMandatory(true)
                .setMaxSize(10)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplateArea.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("title")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.ReportTemplateArea.class);

    /** sql (Database column: SQL - the SQL query) */
    static public AttributeDefinition sql =
        new AttributeDefinition("sql")
                .setDescription("the SQL query")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("REPORT_TEMPLATE_AREA_SQL")
                .setDatabaseId("SQL")
                .setMandatory(true)
                .setMaxSize(4000)
                .setType(String.class);

    /** sqlDataSource (Database column: SQL_DATA_SOURCE_ID - the data source ID) */
    static public AttributeDefinition sqlDataSource =
        new AttributeDefinition("sqlDataSource")
                .setDescription("the data source ID")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("REPORT_TEMPLATE_AREA_SQL")
                .setDatabaseId("SQL_DATA_SOURCE_ID")
                .setMandatory(false)
                .setMaxSize(10)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.SqlDataSource.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.SqlDataSource.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return null;
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(id.getName(),id);
        map.put(name.getName(),name);
        map.put(reportTemplateArea.getName(),reportTemplateArea);
        map.put(sql.getName(),sql);
        map.put(sqlDataSource.getName(),sqlDataSource);

        return map;
    }
}
